==> haskell-crypto-pubkey-types-0.4.3-393-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-crypto-pubkey-types.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 crypto-pubkey-types
version:              0.4.3
visibility:           public
id:                   crypto-pubkey-types-0.4.3-4V8zzGUvSX1CdUtInDMtRu
key:                  crypto-pubkey-types-0.4.3-4V8zzGUvSX1CdUtInDMtRu
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Vincent Hanquez <vincent@snarc.org>
author:               Vincent Hanquez <vincent@snarc.org>
homepage:             http://github.com/vincenthz/hs-crypto-pubkey-types
synopsis:             Generic cryptography Public keys algorithm types
description:          Generic cryptography public keys algorithm types
category:             Cryptography
abi:                  0709785886cacb7919b5e636df1a2b3c
exposed:              True
exposed-modules:
    Crypto.Types.PubKey.DH Crypto.Types.PubKey.DSA
    Crypto.Types.PubKey.ECC Crypto.Types.PubKey.ECDSA
    Crypto.Types.PubKey.RSA

import-dirs:          /usr/lib/ghc-9.4.8/site-local/crypto-pubkey-types-0.4.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/crypto-pubkey-types-0.4.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/crypto-pubkey-types-0.4.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-crypto-pubkey-types
hs-libraries:         HScrypto-pubkey-types-0.4.3-4V8zzGUvSX1CdUtInDMtRu
depends:
    asn1-encoding-0.9.6-KCy4xN7tuIoAGeSy6IbNiw
    asn1-types-0.3.4-F5hXuagZ1J54MQkhvI1flt base-4.17.2.1

haddock-interfaces:
    /usr/share/doc/haskell-crypto-pubkey-types/html/crypto-pubkey-types.haddock

haddock-html:         /usr/share/doc/haskell-crypto-pubkey-types/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-crypto-pubkey-types-0.4.3-394-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-crypto-pubkey-types.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 crypto-pubkey-types
version:              0.4.3
visibility:           public
id:                   crypto-pubkey-types-0.4.3-B0Ql6knzhW7Ge6zCNSr7pP
key:                  crypto-pubkey-types-0.4.3-B0Ql6knzhW7Ge6zCNSr7pP
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Vincent Hanquez <vincent@snarc.org>
author:               Vincent Hanquez <vincent@snarc.org>
homepage:             http://github.com/vincenthz/hs-crypto-pubkey-types
synopsis:             Generic cryptography Public keys algorithm types
description:          Generic cryptography public keys algorithm types
category:             Cryptography
abi:                  c34b27117890aeccdf83c0d0df5bc21a
exposed:              True
exposed-modules:
    Crypto.Types.PubKey.DH Crypto.Types.PubKey.DSA
    Crypto.Types.PubKey.ECC Crypto.Types.PubKey.ECDSA
    Crypto.Types.PubKey.RSA

import-dirs:          /usr/lib/ghc-9.4.8/site-local/crypto-pubkey-types-0.4.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/crypto-pubkey-types-0.4.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/crypto-pubkey-types-0.4.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-crypto-pubkey-types
hs-libraries:         HScrypto-pubkey-types-0.4.3-B0Ql6knzhW7Ge6zCNSr7pP
depends:
    asn1-encoding-0.9.6-6bILbVjk4mj9mjwSmtzJsS
    asn1-types-0.3.4-DyeYGik6KZH5mtLJnPiYPK base-4.17.2.1

haddock-interfaces:
    /usr/share/doc/haskell-crypto-pubkey-types/html/crypto-pubkey-types.haddock

haddock-html:         /usr/share/doc/haskell-crypto-pubkey-types/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
